@@ -3,6 +3,7 @@ use std::{collections::BTreeMap, ops::Sub};
 use cargo_metadata::Package;
 use git_repository as git;
 use git_repository::prelude::ObjectIdExt;
+use time::OffsetDateTime;
 
 use crate::{
     changelog,
@@ -21,21 +22,13 @@ impl Section {
     pub fn from_history_segment(
         package: &Package,
         segment: &commit::history::Segment<'_>,
-        repo: &git::Easy,
+        handle: &git::easy::Handle,
         selection: section::segment::Selection,
+        prev_segment: Option<&commit::history::Segment<'_>>,
     ) -> Self {
-        let time = segment
-            .head
-            .peeled
-            .expect("all refs here are peeled")
-            .attach(repo)
-            .object()
-            .expect("object exists")
-            .to_commit()
-            .committer
-            .time;
+        let date_time = segment_head_time(segment, handle);
+        let prev_date_time = prev_segment.map(|segment| segment_head_time(segment, handle));
 
-        let date_time = time_to_offset_date_time(time);
         let mut segments = Vec::new();
         let history = &segment.history;
         if !history.is_empty() {
@@ -104,6 +97,7 @@ impl Section {
                     section::segment::CommitStatistics {
                         count: history.len(),
                         duration,
+                        time_passed_since_last_release: prev_date_time.map(|prev_time| date_time.sub(prev_time)),
                         conventional_count: history.iter().filter(|item| item.message.kind.is_some()).count(),
                         unique_issues: {
                             let mut v = commits_by_category
@@ -139,7 +133,8 @@ impl Section {
 
         let version = crate::git::try_strip_tag_path(segment.head.name.to_ref())
             .map(|tag_name| {
-                let package_name = (!is_top_level_package(&package.manifest_path, repo)).then(|| package.name.as_str());
+                let package_name =
+                    (!is_top_level_package(&package.manifest_path, handle)).then(|| package.name.as_str());
                 changelog::Version::Semantic(
                     utils::parse_possibly_prefixed_tag_version(package_name, tag_name)
                         .expect("here we always have a valid version as it passed a filter when creating it"),
@@ -162,3 +157,18 @@ impl Section {
         }
     }
 }
+
+fn segment_head_time(segment: &commit::history::Segment<'_>, handle: &git::easy::Handle) -> OffsetDateTime {
+    let time = segment
+        .head
+        .peeled
+        .expect("all refs here are peeled")
+        .attach(handle)
+        .object()
+        .expect("object exists")
+        .to_commit_ref()
+        .committer
+        .time;
+
+    time_to_offset_date_time(time)
+}
