@@ -21,8 +21,6 @@ mod git;
 mod github;
 mod manifest;
 
-type Oid<'repo> = git_repository::easy::Oid<'repo, git_repository::Easy>;
-
 pub(crate) struct Context {
     base: crate::Context,
     changelog_links: Linkables,
@@ -64,18 +62,18 @@ pub fn release(opts: Options, crates: Vec<String>, bump: BumpSpec, bump_dependen
     } else {
         opts.changelog
     };
-    let ctx = Context::new(crates, bump, bump_dependencies, allow_changelog, opts.changelog_links)?;
+
     if opts.update_crates_index {
-        log::info!(
-            "Updating crates-io index at '{}'",
-            ctx.base.crates_index.path().display()
-        );
-        ctx.base.crates_index.update()?;
+        // Do this before creating our context to pick up a possibly newly fetched/created index.
+        log::info!("Updating crates-io index",);
+        crates_index::Index::new_cargo_default()?.update()?;
     } else if opts.bump_when_needed {
         log::warn!(
             "Consider running with --update-crates-index to assure bumping on demand uses the latest information"
         );
     }
+
+    let ctx = Context::new(crates, bump, bump_dependencies, allow_changelog, opts.changelog_links)?;
     if !ctx.base.crates_index.exists() {
         log::warn!("Crates.io index doesn't exist. Consider using --update-crates-index to help determining if release versions are published already");
     }
@@ -124,7 +122,7 @@ fn assure_crates_index_is_uptodate<'meta>(
                 .and_then(|lr| (lr >= &b.desired_release).then(|| d))
         })
     {
-        let index = crates_index::Index::new_cargo_default();
+        let mut index = crate::crates_index::Index::new_cargo_default()?;
         if index.exists() {
             log::warn!("Crate '{}' computed version not greater than the current package version. Updating crates index to assure correct results.", dep.package.name);
             index.update()?;
@@ -409,7 +407,7 @@ fn perform_release(ctx: &Context, options: Options, crates: &[traverse::Dependen
     let mut tag_names = Vec::new();
     let mut successful_publishees_and_version = Vec::new();
     let mut publish_err = None;
-    for (publishee, new_version) in crates.iter().filter_map(|c| try_to_published_crate_and_new_version(c)) {
+    for (publishee, new_version) in crates.iter().filter_map(try_to_published_crate_and_new_version) {
         if let Err(err) = cargo::publish_crate(publishee, options) {
             publish_err = Some(err);
             break;
@@ -418,7 +416,7 @@ fn perform_release(ctx: &Context, options: Options, crates: &[traverse::Dependen
         if let Some(tag_name) = git::create_version_tag(
             publishee,
             new_version,
-            commit_id.clone(),
+            commit_id,
             release_section_by_publishee
                 .get(&publishee.name.as_str())
                 .and_then(|s| section_to_string(s, WriteMode::Tag)),
