@@ -2,18 +2,16 @@ use cargo_metadata::{
     camino::{Utf8Path, Utf8PathBuf},
     Metadata, Package,
 };
-use crates_index::Index;
 use git_repository as git;
-use git_repository::prelude::CacheAccessExt;
 
 use crate::version::BumpSpec;
 
 pub struct Context {
     pub root: Utf8PathBuf,
     pub meta: Metadata,
-    pub repo: git::Easy,
+    pub repo: git::easy::Handle,
     pub crate_names: Vec<String>,
-    pub crates_index: Index,
+    pub crates_index: crate::crates_index::Index,
     pub history: Option<crate::commit::History>,
     pub bump: BumpSpec,
     pub bump_dependencies: BumpSpec,
@@ -28,8 +26,8 @@ impl Context {
     ) -> anyhow::Result<Self> {
         let meta = cargo_metadata::MetadataCommand::new().exec()?;
         let root = meta.workspace_root.clone();
-        let repo = git::discover(&root)?.into_easy().apply_environment()?;
-        let crates_index = Index::new_cargo_default();
+        let repo = git::discover(&root)?.to_easy().apply_environment();
+        let crates_index = crate::crates_index::Index::new_cargo_default()?;
         let history = (force_history_segmentation
             || matches!(bump, BumpSpec::Auto)
             || matches!(bump_dependencies, BumpSpec::Auto))
